@@ -1,6 +1,6 @@
 """
 Transcription System module for consistent IPA handling.
-========================================
+========================================================
 
 """
 import re
@@ -62,11 +62,11 @@ class TranscriptionSystem(TranscriptionBase):
                 c['name'].lower() for c in
                 self.system.tabledict['{0}s.tsv'.format(type_)]
                     .asdict()['tableSchema']['columns']]
-            for l, item in enumerate(itertable(
+            for lnum, item in enumerate(itertable(
                     self.system.tabledict['{0}s.tsv'.format(type_)])):
                 if item['grapheme'] in self.sounds:
                     raise ValueError('duplicate grapheme in {0}:{1}: {2}'.format(
-                        type_ + 's.tsv', l + 2, item['grapheme']))
+                        type_ + 's.tsv', lnum + 2, item['grapheme']))
                 sound = cls(ts=self, **item)
                 # make sure this does not take too long
                 for key, value in item.items():
@@ -76,16 +76,16 @@ class TranscriptionSystem(TranscriptionBase):
                         if type_ != 'marker' and value not in features[type_][key]:
                             raise ValueError(
                                 "Unrecognized features ({0}: {1}, line {2}))".format(
-                                    key, value, l + 2))
+                                    key, value, lnum + 2))
 
                 self.sounds[item['grapheme']] = sound
                 if not sound.alias:
                     if sound.featureset in self.features:
                         raise ValueError('duplicate features in {0}:{1}: {2}'.format(
-                            type_ + 's.tsv', l + 2, sound.name))
+                            type_ + 's.tsv', lnum + 2, sound.name))
                     self.features[sound.featureset] = sound
                 else:
-                    aliases += [(l, sound.type, sound.featureset)]
+                    aliases += [(lnum, sound.type, sound.featureset)]
         # check for consistency of aliases: if an alias has no counterpart, it
         # is orphaned and needs to be deleted or given an accepted non-aliased
         # sound
@@ -107,7 +107,8 @@ class TranscriptionSystem(TranscriptionBase):
 
     def _update_regex(self):
         self._regex = re.compile('|'.join(
-            map(re.escape, sorted(self.sounds, key=lambda x: len(x), reverse=True))))
+            map(re.escape, sorted(self.sounds, key=lambda x: (len(x),
+                -ord(x[0])), reverse=True))))
 
     def _norm(self, string):
         """Extended normalization: normalize by list of norm-characers, split
@@ -145,8 +146,9 @@ class TranscriptionSystem(TranscriptionBase):
                     # try to generate the sounds if they are not there
                     s1, s2 = self._from_name(from_ + ' ' + extension), self._from_name(
                         to_ + ' ' + extension)
-                    if not (isinstance(
-                        s1, UnknownSound) or isinstance(s2, UnknownSound)):  # noqa: F405
+                    if not (
+                            isinstance(s1, UnknownSound)  # noqa: F405
+                            or isinstance(s2, UnknownSound)):  # noqa: F405
                         if sound_class == 'diphthong':
                             return Diphthong.from_sounds(  # noqa: F405
                                 s1 + s2, s1, s2, self)
@@ -191,8 +193,16 @@ class TranscriptionSystem(TranscriptionBase):
             return sound
 
         match = list(self._regex.finditer(nstring))
+
+        if len(match) != 1 and len(match) != 2:
+            # Either no match or more than one; both is considered an error.
+            return UnknownSound(grapheme=nstring, source=string, ts=self)  # noqa: F405
+
         # if the match has length 2, we assume that we have two sounds, so we split
         # the sound and pass it on for separate evaluation (recursive function)
+        # we add a check that makes sure there is no single-match if we take
+        # the second element
+        checked_for_two = False
         if len(match) == 2:
             sound1 = self._parse(nstring[:match[1].start()])
             sound2 = self._parse(nstring[match[1].start():])
@@ -200,23 +210,47 @@ class TranscriptionSystem(TranscriptionBase):
             # we have two known sounds of the same type (vowel or consonant), we
             # either construct a diphthong or a cluster
             if 'unknownsound' not in (sound1.type, sound2.type) and \
-                    sound1.type == sound2.type:
+                    sound1.type == sound2.type and sound1.type in ['consonant', 'vowel']:
                 # diphthong creation
                 if sound1.type == 'vowel':
                     return Diphthong.from_sounds(  # noqa: F405
                         string, sound1, sound2, self)
                 elif sound1.type == 'consonant' and \
                         sound1.manner in ('stop', 'implosive', 'click', 'nasal') and \
-                        sound2.manner in ('stop', 'implosive', 'affricate', 'fricative'):
+                        sound2.manner in ('stop', 'implosive', 'affricate'):
                     return Cluster.from_sounds(  # noqa: F405
                         string, sound1, sound2, self)
-            return UnknownSound(grapheme=nstring, source=string, ts=self)  # noqa: F405
+                elif sound1.type == 'consonant' and sound1.manner == 'click' \
+                        and sound2.manner == 'fricative':
+                    return Cluster.from_sounds(string, sound1, sound2, self)  # noqa: F405
+                # check for plosive plus fricative if they are the same in
+                # manner
+                elif sound1.manner == 'stop' and sound2.manner == 'fricative' \
+                        and sound1.place == sound2.place:
+                    # join features
+                    features = {
+                        f: v or sound2.featuredict[f] for f, v in sound1.featuredict.items()}
+                    features['manner'] = 'affricate'
+                    # new_sound = Consonant(self, nstring, **features)
+                    new_sound = self._from_name(
+                        ' '.join([v for k, v in features.items() if v]) + ' consonant')
+                    return new_sound
 
-        if len(match) != 1:
-            # Either no match or more than one; both is considered an error.
-            return UnknownSound(grapheme=nstring, source=string, ts=self)  # noqa: F405
+            i = 1
+            while i < len(nstring):
+                new_match = list(self._regex.finditer(nstring[i:]))
+                if len(new_match) == 1:
+                    pre, mid, post = nstring[i:].partition(
+                        nstring[i:][new_match[0].start():new_match[0].end()])
+                    pre = nstring[:i] + pre
+                    checked_for_two = True
+                    break
+                i += 1
+            if not checked_for_two:
+                return UnknownSound(grapheme=nstring, source=string, ts=self)  # noqa: F405
 
-        pre, mid, post = nstring.partition(nstring[match[0].start():match[0].end()])
+        if not checked_for_two:
+            pre, mid, post = nstring.partition(nstring[match[0].start():match[0].end()])
         base_sound = self.sounds[mid]
         if isinstance(base_sound, Marker):  # noqa: F405
             assert pre or post
